# coding: utf-8

"""
    Lance Namespace Specification

    This OpenAPI specification is a part of the Lance namespace specification. It contains 2 parts:  The `components/schemas`, `components/responses`, `components/examples`, `tags` sections define the request and response shape for each operation in a Lance Namespace across all implementations. See https://lancedb.github.io/lance-namespace/spec/operations for more details.  The `servers`, `security`, `paths`, `components/parameters` sections are for the  Lance REST Namespace implementation, which defines a complete REST server that can work with Lance datasets. See https://lancedb.github.io/lance-namespace/spec/impls/rest for more details. 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from lance_namespace_urllib3_client.api.data_api import DataApi


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataApi()

    def tearDown(self) -> None:
        pass

    def test_alter_table_add_columns(self) -> None:
        """Test case for alter_table_add_columns

        Add new columns to table schema
        """
        pass

    def test_analyze_table_query_plan(self) -> None:
        """Test case for analyze_table_query_plan

        Analyze query execution plan
        """
        pass

    def test_count_table_rows(self) -> None:
        """Test case for count_table_rows

        Count rows in a table
        """
        pass

    def test_create_table(self) -> None:
        """Test case for create_table

        Create a table with the given name
        """
        pass

    def test_delete_from_table(self) -> None:
        """Test case for delete_from_table

        Delete rows from a table
        """
        pass

    def test_explain_table_query_plan(self) -> None:
        """Test case for explain_table_query_plan

        Get query execution plan explanation
        """
        pass

    def test_insert_into_table(self) -> None:
        """Test case for insert_into_table

        Insert records into a table
        """
        pass

    def test_merge_insert_into_table(self) -> None:
        """Test case for merge_insert_into_table

        Merge insert (upsert) records into a table
        """
        pass

    def test_query_table(self) -> None:
        """Test case for query_table

        Query a table
        """
        pass

    def test_update_table(self) -> None:
        """Test case for update_table

        Update rows in a table
        """
        pass


if __name__ == '__main__':
    unittest.main()
